#!/usr/bin/perl -w

# Copyright 2022 Kevin Ryde

# This file is part of OEIS-data.
#
# OEIS-data is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 3, or (at your option) any later
# version.
#
# OEIS-data is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License along
# with OEIS-data.  If not, see <http://www.gnu.org/licenses/>.


use 5.006;
use strict;
use warnings;
use File::Spec;
use FindBin;
use Math::OEIS;
use Test::More tests => 19;
BEGIN { $|=1; }

# uncomment this to run the ### lines
# use Smart::Comments;

my $bindir; BEGIN { $bindir = $FindBin::Bin; }
### $bindir
use lib $bindir;
use MyTestHelpers;
BEGIN { MyTestHelpers::nowarnings() }

# Math::OEIS ~/OEIS
$ENV{'HOME'} = $bindir;
### HOME: $ENV{'HOME'}

# ../OEIS-data-reader
my $OEIS_data_reader_script
  = File::Spec->catfile($bindir,
                        File::Spec->updir,
                        'OEIS-data-reader');
### $OEIS_data_reader_script

our ($anum,$action,@flags,$flag_offset,$flag_bfile);
our ($number_re,$numbers_re);
my $action_noop;
sub action__noop { $action_noop++; }

@ARGV = ('--anum',   'A000000',
         '--action', 'noop',
         '--flag',   '0');
do $OEIS_data_reader_script;
is($action_noop, 1, 'action_noop called');
is($flag_offset, undef);
is($flag_bfile, undef);

sub run_reader {
  my ($anum) = @_;
  @ARGV = ('--anum', $anum,
           '--action', 'noop',
           '--flag',   '0');
  main();
}

#------------------------------------------------------------------------------
# internal_data()

run_reader('A820000');
is(internal_data(), '9,8,7,6,5,4,4,4');


#------------------------------------------------------------------------------
# $number_re

my $all_number_re = qr/^$number_re$/o;
like ('0', $all_number_re);
like ('1', $all_number_re);
like ('123', $all_number_re);
like ('-1', $all_number_re);
like ('-123', $all_number_re);

unlike ('-0', $all_number_re);
unlike ('-0123', $all_number_re);
unlike ('0123', $all_number_re);
unlike ('1.5', $all_number_re);


#------------------------------------------------------------------------------
my $all_numbers_re = qr/^$numbers_re$/o;

like ('1,2,3,123,999', $all_numbers_re);
unlike ('1,2,3 123,999', $all_numbers_re);
unlike ("999 888", $all_numbers_re);





#------------------------------------------------------------------------------
# Math::OEIS Setups

{
  my $want = File::Spec->catfile($bindir,'OEIS');
  my @dirs = Math::OEIS->local_directories();
  is (join("\n",@dirs),
      $want,
      'local_directories() faked');
}

#------------------------------------------------------------------------------
# bfile_filename()
{
  run_reader('A800000');
  my $want = File::Spec->catfile($bindir,'OEIS');
  is (bfile_filename(),
      File::Spec->catfile($bindir,
                          'OEIS',
                          'b800000.txt'),
      'bfile_filename()');
}

#------------------------------------------------------------------------------
# bfile_offset()

# OEIS/b800000.txt
{
  run_reader('A800000');
  is(bfile_offset(), 42,
     'bfile_offset()');
}


#-----------------------------------------------------------------------------

# Local variables:
# compile-command: "perl -w data-reader.t"
# End:
